using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

// Steema namespaces
using Steema.TeeChart;
using Steema.TeeChart.Styles;


namespace PolarPlotTest
{
    public partial class Form1 : Form
    {
        /// <summary>
        /// The TeeChart chart object used to draw graphs on. Line and points wil be added to
        /// this.
        /// </summary>
        private TChart[] chart;

        /// <summary>
        /// The balance data
        /// </summary>
        private Steema.TeeChart.Styles.PolarBar balanceData3Points;
        private Steema.TeeChart.Styles.PolarBar balanceData2Points;

        /// <summary>
        /// Markstips
        /// </summary>
        private Steema.TeeChart.Tools.MarksTip markTip;

        /// <summary>
        /// The Axis array
        /// </summary>
        private Axis[] axises;

        /// <summary>
        /// X and T captions
        /// </summary>
        private string xCaption = "Magnitude";
        private string yCaption = "Phase";


        public Form1()
        {
            InitializeComponent();

            initialise();

            addData3Points();
            addData2Points();

            _scChartGrid.Panel1.Controls.Add(chart[0]);
            _scChartGrid.Panel2.Controls.Add(chart[1]);
        }

        private void initialise()
        {
            //
            // Local Declarations
            //

            //
            // Start of Operation
            //
            // Create a new chart obect
            chart = new TChart[2];

            for (int chartLoop = 0; chartLoop < chart.Length; chartLoop++)
            {
                // Create the chart and set the chart dock to fill space available
                chart[chartLoop] = new TChart();
                chart[chartLoop].Dock = System.Windows.Forms.DockStyle.Fill;

                // Set the chart title
                chart[chartLoop].Text = "Polar Bar Test Chart: " + ((int)(chartLoop+1)).ToString();

                // Set the chart cursor
                chart[chartLoop].Cursor = System.Windows.Forms.Cursors.Cross;

                // Set the TChart aspects
                chart[chartLoop].Aspect.View3D = false;
                chart[chartLoop].Aspect.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.HighQuality;

                // Set the TChart footer and headers
                chart[chartLoop].Footer.Font.Shadow.Visible = false;
                chart[chartLoop].Footer.Font.Unit = System.Drawing.GraphicsUnit.World;

                // Turn off footer shadow
                chart[chartLoop].Footer.Shadow.Visible = false;

                chart[chartLoop].Header.Font.Shadow.Visible = false;
                chart[chartLoop].Header.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].Header.Lines = new string[] { "Polar Bar Test" };

                // Turn off header shadow
                chart[chartLoop].Header.Shadow.Visible = false;

                // Set the TChart legend
                chart[chartLoop].Legend.Font.Shadow.Visible = false;
                chart[chartLoop].Legend.Font.Unit = System.Drawing.GraphicsUnit.World;

                // Turn off legend shadow
                chart[chartLoop].Legend.Shadow.Visible = false;

                // Set the legend title attributes
                chart[chartLoop].Legend.Title.Font.Bold = true;
                chart[chartLoop].Legend.Title.Font.Shadow.Visible = false;
                chart[chartLoop].Legend.Title.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].Legend.Title.Pen.Visible = false;

                // Tuen the legend off
                chart[chartLoop].Legend.Visible = false;

                // Set the chart location
                chart[chartLoop].Location = new System.Drawing.Point(0, 0);
                chart[chartLoop].Panel.MarginBottom = 3;
                chart[chartLoop].Panel.MarginTop = 1;

                chart[chartLoop].Panel.Shadow.Visible = false;

                // Set the chart sub-footer, do not want to display
                chart[chartLoop].SubFooter.Font.Shadow.Visible = false;
                chart[chartLoop].SubFooter.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].SubHeader.Font.Shadow.Visible = false;
                chart[chartLoop].SubHeader.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].SubFooter.Shadow.Visible = false;
                chart[chartLoop].SubHeader.Shadow.Visible = false;
                chart[chartLoop].TabIndex = 0;

                // Set the chart walls, do not want to display
                chart[chartLoop].Walls.Back.AutoHide = false;
                chart[chartLoop].Walls.Back.Shadow.Visible = false;

                chart[chartLoop].Walls.Bottom.AutoHide = false;
                chart[chartLoop].Walls.Bottom.Shadow.Visible = false;

                chart[chartLoop].Walls.Left.AutoHide = false;
                chart[chartLoop].Walls.Left.Shadow.Visible = false;

                chart[chartLoop].Walls.Right.AutoHide = false;
                chart[chartLoop].Walls.Right.Shadow.Visible = false;

                chart[chartLoop].Walls.Visible = false;

                ///////////////////////////////////////////////////////////////////////////////////////////////////
                // Common TChart Axes Settings
                chart[chartLoop].Axes.DrawBehind = false;

                ///////////////////////////////////////////////////////////////////////////////////////////////////
                // Set the TChart Bottom (X) Axes
                chart[chartLoop].Axes.Bottom.MaximumRound = true;
                chart[chartLoop].Axes.Bottom.MinimumRound = true;

                chart[chartLoop].Axes.Bottom.Grid.Style = System.Drawing.Drawing2D.DashStyle.Dash;
                chart[chartLoop].Axes.Bottom.Grid.ZPosition = 0;

                // Set the axis lable style
                chart[chartLoop].Axes.Bottom.Labels.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Bottom.Labels.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].Axes.Bottom.Labels.Shadow.Visible = false;

                // Set the X (bottom) axis caption
                if ((xCaption != null) && (xCaption != ""))
                {
                    chart[chartLoop].Axes.Bottom.Title.Caption = xCaption;
                }
                chart[chartLoop].Axes.Bottom.Title.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Bottom.Title.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].Axes.Bottom.Title.Shadow.Visible = false;

                ///////////////////////////////////////////////////////////////////////////////////////////////////
                // Set the TChart Left (Y) Axes

                // Set the TChart Left Axes
                chart[chartLoop].Axes.Left.MaximumRound = true;
                chart[chartLoop].Axes.Left.MinimumRound = true;

                chart[chartLoop].Axes.Left.Grid.Style = System.Drawing.Drawing2D.DashStyle.Dash;
                chart[chartLoop].Axes.Left.Grid.ZPosition = 0;

                // Set the X (bottom) axis caption
                chart[chartLoop].Axes.Left.Title.Caption = yCaption;
                if ((yCaption != null) && (yCaption != ""))
                {
                    chart[chartLoop].Axes.Left.Title.Caption = yCaption;
                }
                chart[chartLoop].Axes.Left.Labels.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Left.Labels.Font.Unit = System.Drawing.GraphicsUnit.World;
                chart[chartLoop].Axes.Left.Labels.Shadow.Visible = false;

                chart[chartLoop].Axes.Left.Title.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Left.Title.Font.Unit = System.Drawing.GraphicsUnit.World;

                chart[chartLoop].Axes.Left.Title.Shadow.Visible = false;

                // Set the Z axis caption
                chart[chartLoop].Axes.Depth.Grid.ZPosition = 0;
                chart[chartLoop].Axes.Depth.Labels.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Depth.Labels.Shadow.Visible = false;
                chart[chartLoop].Axes.Depth.Title.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.Depth.Title.Shadow.Visible = false;
                chart[chartLoop].Axes.DepthTop.Grid.ZPosition = 0;
                chart[chartLoop].Axes.DepthTop.Labels.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.DepthTop.Labels.Shadow.Visible = false;
                chart[chartLoop].Axes.DepthTop.Title.Font.Shadow.Visible = false;
                chart[chartLoop].Axes.DepthTop.Title.Shadow.Visible = false;

                // Set the chart aspect
                chart[chartLoop].Aspect.Elevation = 315;
                chart[chartLoop].Aspect.Orthogonal = false;
                chart[chartLoop].Aspect.Perspective = 0;
                chart[chartLoop].Aspect.Rotation = 360;
                chart[chartLoop].Aspect.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.HighQuality;
                chart[chartLoop].Aspect.TextRenderingHint = System.Drawing.Text.TextRenderingHint.ClearTypeGridFit;
                chart[chartLoop].Aspect.View3D = false;
            }
        }

        private void addData3Points()
        {
            //
            // Local Declarations
            //

            //
            // Start of Operation
            //
            // Create the series
            balanceData3Points = new Steema.TeeChart.Styles.PolarBar();

            // Set the X Values
            balanceData3Points.XValues.DataMember = "Angle";
            balanceData3Points.XValues.Order = Steema.TeeChart.Styles.ValueListOrder.Ascending;

            // Set the Y Values
            balanceData3Points.YValues.DataMember = "Y";

            // Make the line clickable
            balanceData3Points.Pointer.Visible = true;

            // Make the plot cicular
            balanceData3Points.Circled = true;

            // Request circle lables and rotate through 90 degrees
            balanceData3Points.CircleLabels = true;
            balanceData3Points.CircleLabelsRotated = true;
            balanceData3Points.RotationAngle = 90;

            // Set lable direction as clock wise
            balanceData3Points.ClockWiseLabels = false;

            // Set the pointer style
            balanceData3Points.Pointer.Style = PointerStyles.PolishedSphere;

            // Create the markstip tool 
            markTip = new Steema.TeeChart.Tools.MarksTip();

            // Add markstip tool to the charts.
            chart[0].Tools.Add(this.markTip);

            // Set the style for label values
            markTip.Style = MarksStyles.XY;
            markTip.MouseAction = Steema.TeeChart.Tools.MarksTipMouseAction.Move;
            markTip.MouseDelay = 150;
            markTip.HideDelay = 10000;

            // Set the event handler
            markTip.GetText += new Steema.TeeChart.Tools.MarksTipGetTextEventHandler(markTipGetText);

            // Assign the series to the tool
            this.markTip.Series = balanceData3Points;


            balanceData3Points.Add(80, 100, "", Color.Red);
            balanceData3Points.Add(200, 80, "", Color.Green);
            balanceData3Points.Add(220, 60, "", Color.Violet);

            chart[0].Axes.Left.SetMinMax(0, 100);
            chart[0].Series.Add(balanceData3Points);
        }

        private void addData2Points()
        {
            //
            // Local Declarations
            //

            //
            // Start of Operation
            //
            // Create the series
            balanceData2Points = new Steema.TeeChart.Styles.PolarBar();

            // Set the X Values
            balanceData2Points.XValues.DataMember = "Angle";
            balanceData2Points.XValues.Order = Steema.TeeChart.Styles.ValueListOrder.Ascending;

            // Set the Y Values
            balanceData2Points.YValues.DataMember = "Y";

            // Make the line clickable
            balanceData2Points.Pointer.Visible = true;

            // Make the plot cicular
            balanceData2Points.Circled = true;

            // Request circle lables and rotate through 90 degrees
            balanceData2Points.CircleLabels = true;
            balanceData2Points.CircleLabelsRotated = true;
            balanceData2Points.RotationAngle = 90;

            // Set lable direction as clock wise
            balanceData2Points.ClockWiseLabels = false;

            // Set the pointer style
            balanceData2Points.Pointer.Style = PointerStyles.PolishedSphere;

            // Create the markstip tool 
            markTip = new Steema.TeeChart.Tools.MarksTip();

            // Add markstip tool to the charts.
            chart[1].Tools.Add(this.markTip);

            // Set the style for label values
            markTip.Style = MarksStyles.XY;
            markTip.MouseAction = Steema.TeeChart.Tools.MarksTipMouseAction.Move;
            markTip.MouseDelay = 150;
            markTip.HideDelay = 10000;

            // Set the event handler
            markTip.GetText += new Steema.TeeChart.Tools.MarksTipGetTextEventHandler(markTipGetText);

            // Assign the series to the tool
            this.markTip.Series = balanceData2Points;


            balanceData2Points.Add(80, 100, "", Color.Red);
            balanceData2Points.Add(190, 50, "", Color.Blue);

            chart[1].Series.Add(balanceData2Points);
            chart[1].Axes.Left.SetMinMax(0, 100);
        }

        /// <summary>
        /// Default mark tip event handler. 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void markTipGetText(Steema.TeeChart.Tools.MarksTip sender, Steema.TeeChart.Tools.MarksTipGetTextEventArgs e)
        {
            //
            // Local Declarations
            //
            string[] xyValues;

            //
            // Start of Operation
            //
            // Seperate the X and Y values
            xyValues = e.Text.Split(' ');
            if (xyValues.Length == 2)
            {
                if (Convert.ToDouble(xyValues[1]) > 0.0)
                {
                    e.Text = "Magnitude: " + xyValues[1] + "ips\nat :" + xyValues[0] + " degrees";
                }
                else
                {
                    e.Text = "";
                }
            }
        }

    }
}